from .. import Provider as BaseProvider


class Provider(BaseProvider):
    jobs = [
        "Aktyor",
        "Akustik Mühəndisi",
        "Allerqoloq",
        "Analitik",
        "Androloq",
        "Antropoloq",
        "Aqronom",
        "Aqronom-Torpaqşünas",
        "Arxeoloq",
        "Arxivçi",
        "Astrofizik",
        "Astronom",
        "Aviatexnik",
        "Bakterioloq",
        "Bankir",
        "Barmen",
        "Biokimyaçı",
        "Bioloq",
        "Biomühəndis",
        "Blogger",
        "Botanik",
        "Cihazqayırma və idarəetmə mühəndisi",
        "Coğrafiyaçı",
        "Cərrah",
        "DJ",
        "Dalğıc",
        "Daşçı",
        "Dekan",
        "Dermatoloq",
        "Diler",
        "Diplomat",
        "Diplomatik işçi",
        "Dirijyor",
        "Dispetçer",
        "Dizayner",
        "Dizayner-konstruktor",
        "Dülgər",
        "Elektrikçi",
        "Enerji Mühəndisi",
        "Genetik",
        "Geoloq",
        "Ginekoloq",
        "Gitarist",
        "Gəmi kapitanı",
        "Hematoloq",
        "Hepatoloq",
        "Hidrolik Mühəndis",
        "Hidroloq",
        "Hüquqşünas",
        "Hərbi Hakim",
        "Hərbi Məsləhətçi",
        "Hərbi Polis",
        "Hərbi Prokuror",
        "Hərbi müstəntiq",
        "Hərbi tərcüməçi",
        "Hərbi vəkil",
        "Hərbçi",
        "Jurnalist",
        "Kardioloq",
        "Kimya mühəndisi",
        "Kitabxanaçı",
        "Kolleksiyaçı",
        "Makler",
        "Memar",
        "Mexanik",
        "Mexanika Mühəndisi",
        "Mühasib",
        "Mühəndis",
        "Mühəndis-Fizik",
        "Mühəndis-laboratoriya köməkçisi",
        "Müstəntiq",
        "Mədənçi",
        "Paraşütçü",
        "Partlayıcı Mühəndis",
        "Pilot",
        "Qastroenteroloq",
        "Qulluqçu",
        "Qumbara Atıcı",
        "Reklam dizayneri",
        "Sistem Mühəndisi",
        "Stüardessa",
        "Sürücü",
        "Səs mühəndisi",
        "Tarixçi",
        "Torpaqçı",
        "Təcili yardım həkimi",
        "Təhlükəsizlik Mühəndisi",
        "Təmizlikçi",
        "Təxribatçı",
        "Uçuş mühəndisi",
        "Veb Proqramçı",
        "Verilənlər bazası administratoru",
        "Viroloq",
        "Vizajist",
        "Vokalçı",
        "Webmaster",
        "Xoreoqraf",
        "Zooloq",
        "Zootexnik",
        "Zərgər",
        "Çörəkçi",
        "İmmunoloq",
        "İnfeksionist",
        "İnşaat mühəndisi",
        "İşsiz",
        "Şərqşünas",
    ]
